package
Version:
v0.10.0
Opens a new window with list of versions in this module.
Published: Mar 10, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AiAgent struct {
AgentName string `yaml:"name" default:"gemini"`
Arguments []string `yaml:"arguments" default:"[-i]"`
}
type Arg struct {
Query string `yaml:"query"`
Options []string `yaml:"options"`
}
type Prompt struct {
Agent AiAgent `yaml:"agent"`
Args []Arg `yaml:"args"`
Template string `yaml:"template"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.