release

package
v0.12.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 7 Imported by: 0

README

Release

Simple tool used to create a release (as a tag) for a github repository. Meant to be added to repositories (like this one) that use tagging as a way to kick off/generate releases.

Configuration

release:

Usage

sre release

The above will generate a git tag and trigger your release if it is coupled with a GH workflow like this.

Description

The release cmd does a simple git tag and push and assumes the GH workflow covers the rest. Future upgrades will likely include a better UI with more content, and configuration that limits what can be done such as prohibiting major version bumps.

Documentation

Index

Constants

const (
	BumpMajor bumpType = iota
	BumpMinor
	BumpPatch
)

Variables

This section is empty.

Functions

func Command

func Command() *cobra.Command

Types

This section is empty.

Jump to